@@ -23,7 +23,13 @@ def createNestedFrame(df1, name, keycolumns=[], partitionkeys=[]):
     newcolumns.append(name)
 
     # Do not put key joining columns into nested structures
-    nonkeycolumns = list(set(df1.columns)-set(keycolumns)-set(partitionkeys))
+    # Old logic reordered columns
+    #     nonkeycolumns = list(set(df1.columns)-set(keycolumns)-set(partitionkeys))
+    ignore_set = set(keycolumns).union(set(partitionkeys))
+    nonkeycolumns = []
+    for c in df1.columns:
+        if not (c in ignore_set):
+            nonkeycolumns.append(c)
 
     df = df1.withColumn(name, struct(nonkeycolumns)).select(newcolumns)
     df = df.groupby(keycolumns).agg(collect_list(name).alias(name))
