@@ -13,7 +13,6 @@ def fetchFromGithub(repo_url="https://api.github.com/repos/<USER>/<REPO>/content
     if response and response.status_code == 200:
         binary_content = base64.b64decode(response.json()["content"])
         content = binary_content.decode("utf-8")
-        jsontext = json.loads(content)
-        return jsontext
+        return content
     else:
         raise Exception("Unable to download "+repo_url+": "+response)
